# -*- coding: utf-8 -*-

from django.core.management.base import BaseCommand
from django.conf import settings

import os

from guichet.models import PaypalAccount


class Command(BaseCommand):
    help = "Alerte pour les paiement paypal par bouton chiffré."

    def handle(self, *args, **options):
        for accounts in PaypalAccount.objects.all():
            if accounts.secure_form and not accounts.secure_available():
                self.stderr.write(
                    "Désactivation du bouton chiffré pour le compte Paypal {}."
                    "Certificat expiré ?".format(accounts.email)
                )
                accounts.secure_form = False
                accounts.save()
            elif accounts.secure_form and not os.path.isfile(accounts.get_cert_priv()):
                self.stderr.write(
                    "Désactivation du bouton chiffré pour le compte Paypal {}."
                    "Certificat privé ({}) introuvable".format(accounts.email, accounts.get_cert_priv())
                )
                accounts.secure_form = False
                accounts.save()
            elif accounts.secure_form and not os.path.isfile(accounts.get_cert_pub()):
                self.stderr.write(
                    "Désactivation du bouton chiffré pour le compte Paypal {}."
                    "Certificat public ({}) introuvable".format(accounts.email, accounts.get_cert_pub())
                )
                accounts.secure_form = False
                accounts.save()

        if settings.DEBUG:
            self.stdout.write("Verifications completed.")
